@@ -6,7 +6,7 @@ use JSON::PP ();
 use constant { true => JSON::PP::true, false => JSON::PP::false };
 
 use JSON::MaybeXS;
-my $encoder = JSON::MaybeXS->new(allow_nonref => 1, utf8 => 0, allow_bignum => 1, allow_blessed => 1);
+my $encoder = JSON::MaybeXS->new(allow_nonref => 1, utf8 => 0);
 
 # like sprintf, but all list items are JSON-encoded. assumes placeholders are %s!
 sub json_sprintf {
